#!/bin/sh
# the next line restarts using wish \
exec wish "$0" "$@"

#############################################################################
# PgcEdit.tcl Copyright 2004, 2005, 2006, 2007, 2008 r0lZ
# Program launcher to define the character encoding.
#
# This file is part of PgcEdit.
#
# PgcEdit is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# PgcEdit is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#############################################################################

#############################################################################
#
# PgcEdit requires Tcl/Tk 8.4 or greather
#
#############################################################################

# Character encoding nightmare!
#
# This file is necessary to define the character encoding needed by the system
# before loading PgcEdit.tcl.
#
# If PgcEdit has trouble with accented characters in file names, set the system
# environment variable PGCEDIT_ENCODING to the character encoding used by your
# system.
#
# cp1252 is the default encoding used by freeWrap. It might be needed to change
# it on foreign systems with accented characters in filenames, or in versions
# of PgcEdit translated in foreign languages.

set encoding cp1252

if {[info exists ::env(PGCEDIT_ENCODING)]} {
	set encoding $::env(PGCEDIT_ENCODING)
}
if {$argc > 0} {
	for {set i 0} {$i < $argc} {incr i} {
	    foreach j {-e= -encoding= /e= /E= /encoding= PGCEDIT_ENCODING=} {
			if {[string first $j [lindex $argv $i]] == 0} {
			    set encoding [string range [lindex $argv $i] [string length $j] end]
				set argv [lreplace $argv $i $i]
				incr argc -1
			}
		}
	    foreach j {-h -help --help /? /help} {
			if {[lindex $argv $i] == $j} {
				set usage true
				set argv [lreplace $argv $i $i]
				incr argc -1
			}
		}
	}
	unset i j
}

if {[catch {encoding system /tcl/encoding/$encoding}]} {
	catch {encoding system $encoding}
}
if {[file tail [encoding system]] != $encoding} {
    set usage true
    puts "Error setting the character encoding to \"$encoding\"!"
}

# launch PgcEdit
if {[file exists PgcEdit_main.tcl]} {
	source PgcEdit_main.tcl
} else {
	source /Tcl/work/PGCEDIT/PgcEdit_main.tcl
}
